<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use common\logic\Ticket\Ticket\Model\TicketSearch;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;
use yii\web\NotFoundHttpException;

class SupportController extends BackendController
{
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                ],
            ],
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserManager()->hasAccessBackend();
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        $searchTicket = new TicketSearch();
        $dataProviderTicket = $searchTicket->search(\Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchTicket' => $searchTicket,
            'dataProviderTicket' => $dataProviderTicket
        ]);
    }

    public function actionCreate()
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $ticketManager->instanciateTicket($this->getProducerCurrent(), $this->getUserCurrent());

        if ($ticket->load(\Yii::$app->request->post()) && $ticketManager->saveCreate($ticket)) {
            $this->setFlash('success', 'Le ticket a bien été créé.');
            return $this->redirect(['index']);
        } else {
            return $this->render('create', [
                'ticket' => $ticket,
            ]);
        }
    }

    public function actionView(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $this->findTicket($id);
        return $this->render('view', [
            'ticket' => $ticket
        ]);
    }

    public function actionClose(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $this->findTicket($id);
        $ticketManager->closeTicket($ticket);
        $this->addFlash('success', "Le ticket a bien été fermé.");
        return $this->redirect(['index']);
    }

    public function actionOpen(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $this->findTicket($id);
        $ticketManager->openTicket($ticket);
        $this->addFlash('success', "Le ticket a bien été ouvert.");
        return $this->redirect(['index']);
    }

    public function findTicket(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $ticketManager->findOneTicketById($id);

        if($ticket && $ticketManager->hasTicketAccess($ticket, $this->getUserCurrent())) {
            return $ticket;
        }
        else {
            throw new NotFoundHttpException("Le ticket est introuvable.");
        }
    }
}
