<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\logic\Ticket\Ticket\Model\Ticket;
use common\logic\Ticket\Ticket\Wrapper\TicketManager;
use yii\helpers\Html;
use yii\grid\GridView;
use common\logic\Subscription\Subscription\Model\Subscription;

$ticketManager = TicketManager::getInstance();
$this->setTitle('Support');
$this->addBreadcrumb($this->getTitle());
//$this->addButton(['label' => 'Créer un ticket <span class="glyphicon glyphicon-plus"></span>', 'url' => 'support/create', 'class' => 'btn btn-primary']) ;

?>
<div class="support-index">

    <div>
        <div class="col-md-4">
            <div class="info-box">
                <span class="info-box-icon bg-yellow"><i class="fa fa-phone"></i></span>
                <div class="info-box-content">
                    <span class="info-box-text">Me contacter directement</span>
                    <span class="info-box-text">
                        <br/>
                        <strong><?= Yii::$app->params['phoneNumber'] ?></strong>
                    </span>
                </div>
            </div>
        </div>
        <div class="col-md-4">
            <div class="info-box">
                <span class="info-box-icon bg-yellow"><i class="fa fa-calendar"></i></span>
                <div class="info-box-content">
                    <span class="info-box-text"><br/>
                            <?= Html::a('Prendre rendez-vous', Yii::$app->params['appointmentUrl'], ['class' => 'btn btn-sm btn-default', 'target' => '_blank']); ?>
                    </span>
                </div>
            </div>
        </div>
        <div class="col-md-4">
            <div class="info-box">
                <span class="info-box-icon bg-yellow"><i class="fa fa-comments"></i></span>
                <div class="info-box-content">
                    <span class="info-box-text"><br/><?= Html::a('Ouvrir un ticket', ['support/create'], ['class' => 'btn btn-sm btn-default']); ?></span>
                </div>
            </div>
        </div>
    </div>

    <div class="clr"></div>

    <div class="box">
        <div class="box-header with-border">
            <h3 class="box-title">Tickets</h3>
        </div>

        <div class="box-body">
            <?= GridView::widget([
                'filterModel' => $searchTicket,
                'dataProvider' => $dataProviderTicket,
                'columns' => [
                    [
                        'attribute' => 'subject',
                        'format' => 'raw',
                        'value' => function($ticket) {
                            return Html::a($ticket->subject, ['support/view', 'id' => $ticket->id]);
                        }
                    ],
                    [
                        'attribute' => 'status',
                        'filter' => [Ticket::STATUS_OPEN => 'Ouvert', Ticket::STATUS_CLOSED => 'Fermé'],
                        'value' => function($ticket) {
                            $label = $ticket->status == Ticket::STATUS_OPEN ? 'Ouvert' : 'Fermé';
                            return $label;
                        }
                    ],
                    [
                        'class' => 'yii\grid\ActionColumn',
                        'template' => '{close-open}',
                        'headerOptions' => ['class' => 'column-actions'],
                        'contentOptions' => ['class' => 'column-actions'],
                        'buttons' => [
                            'close-open' => function ($url, $ticket) use ($ticketManager) {
                                if($ticketManager->isTicketOpen($ticket)) {
                                    $title = 'Fermer';
                                    $url = ['support/close', 'id' => $ticket->id];
                                    $glyphicon = 'glyphicon-folder-close';
                                }
                                else {
                                    $title = 'Ré-ouvrir';
                                    $url = ['support/open', 'id' => $ticket->id];
                                    $glyphicon = 'glyphicon-folder-open';
                                }
                                return Html::a('<span class="glyphicon '.$glyphicon.'"></span>', $url, [
                                    'title' => $title, 'class' => 'btn btn-default'
                                ]);
                            }
                        ],
                    ],
                ],
            ]); ?>
        </div>
    </div>

</div>
